summaryrefslogtreecommitdiff
path: root/Build/source/texk/dvipdfm-x/spc_pdfm.c
diff options
context:
space:
mode:
authorKhaled Hosny <khaledhosny@eglug.org>2014-07-29 07:10:49 +0000
committerKhaled Hosny <khaledhosny@eglug.org>2014-07-29 07:10:49 +0000
commit117d1038285bced4517dbc0313a0bb3f799961ed (patch)
treed1e82b97f0942e0a94a550b9a2792235df6c40d3 /Build/source/texk/dvipdfm-x/spc_pdfm.c
parent2c82e6c5f9624187e7abd78c1bfd66663b72deaf (diff)
Rename is_xetex to is_xdv
git-svn-id: svn://tug.org/texlive/trunk@34766 c570f23f-e606-0410-a88d-b1316a301751
Diffstat (limited to 'Build/source/texk/dvipdfm-x/spc_pdfm.c')
-rw-r--r--Build/source/texk/dvipdfm-x/spc_pdfm.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/Build/source/texk/dvipdfm-x/spc_pdfm.c b/Build/source/texk/dvipdfm-x/spc_pdfm.c
index 2636a984bf8..5eb2dba61f5 100644
--- a/Build/source/texk/dvipdfm-x/spc_pdfm.c
+++ b/Build/source/texk/dvipdfm-x/spc_pdfm.c
@@ -532,7 +532,7 @@ modstrings (pdf_obj *kp, pdf_obj *vp, void *dp)
CMap *cmap = CMap_cache_get(cd->cmap_id);
if (needreencode(kp, vp, cd))
r = reencodestring(cmap, vp);
- } else if (is_xetex)
+ } else if (is_xdv)
r = maybe_reencode_utf8(vp);
if (r < 0) /* error occured... */
WARN("Failed to convert input string to UTF16...");
@@ -553,8 +553,8 @@ parse_pdf_dict_with_tounicode (const char **pp, const char *endptr, struct touni
{
pdf_obj *dict;
-/* disable this test for xdvipdfmx, as we do utf8 reencoding with no cmap */
- if (!is_xetex && cd->cmap_id < 0)
+ /* disable this test for XDV files, as we do UTF8 reencoding with no cmap */
+ if (!is_xdv && cd->cmap_id < 0)
return parse_pdf_dict(pp, endptr, NULL);
/* :( */
@@ -1077,7 +1077,7 @@ spc_handler_pdfm_dest (struct spc_env *spe, struct spc_arg *args)
return -1;
}
- if (is_xetex && maybe_reencode_utf8(name) < 0)
+ if (is_xdv && maybe_reencode_utf8(name) < 0)
WARN("Failed to convert input string to UTF16...");
array = parse_pdf_object(&args->curptr, args->endptr, NULL);